import React from 'react';
import AceEditor from "react-ace";
import ReactSwitch from "react-switch";

import "ace-builds/src-noconflict/mode-css";
import "ace-builds/src-noconflict/theme-monokai";

class SettingsFrom extends React.Component {

  constructor(props) {
    super(props);

    this.handleCacheTimeChange = this.handleCacheTimeChange.bind(this);
    this.onCssChange = this.onCssChange.bind(this);
    this.onLoadMoreOptionChange = this.onLoadMoreOptionChange.bind(this);
    this.onTextFieldChange = this.onTextFieldChange.bind(this);
  }

  render() {
    var {
      cache_time,
      custom_css,
      show_load_more_button,
      load_more_button_text
    } = this.props.form;

    return (
      <div>
        <div className="gs-instagram-settings-field">
          <div className="gs-label">
            <label>Cache Time</label>
            <p>Set your posts cache time here. We will cache your Instagram posts to give you better performance. Minimum value is 10 minutes.</p>
          </div>
          <div className="gs-input">
            <input type="number" placeholder="Time in minutes" className="default-input" name="cache_time"
              value={cache_time} onChange={this.handleCacheTimeChange}
            />
          </div>
        </div>

        <div className="gs-instagram-settings-field">
          <div className="gs-label">
            <label>Custom CSS</label>
            <p>You can write your own custom css. These codes will be added to every pages.</p>
          </div>
          <div className="gs-input">
            <AceEditor
              mode="css"
              theme="monokai"
              onChange={this.onCssChange}
              value={custom_css}
              fontSize={14}
              showPrintMargin={true}
              showGutter={true}
              highlightActiveLine={true}
              setOptions={{
                showLineNumbers: true,
                tabSize: 2,
                useWorker: false
              }}
              width="100%"
              height="300px"
            />
          </div>
        </div>

        <div className="gs-instagram-settings-field">
          <div className="gs-label">
            <label>Load More Button</label>
            <p>Do you want to show Load More button below posts grid. Default value is <strong>Show</strong>.</p>
          </div>
          <div className="gs-input">
            <ReactSwitch
              onChange={this.onLoadMoreOptionChange}
              checked={ Boolean(Number(show_load_more_button)) }
              checkedIcon={<div className="react-switch-icon left-icon">Show</div>}
              uncheckedIcon={<div className="react-switch-icon right-icon">Hide</div>}
              width={80}
              height={32}
              handleDiameter={26}
            />
          </div>
        </div>

        <div className="gs-instagram-settings-field">
          <div className="gs-label">
            <label>Load More Button Text</label>
            <p>What will be the text of load more button. Default value is <strong>Load More</strong>.</p>
          </div>
          <div className="gs-input">
            <input type="text" placeholder="Text of load more button" className="default-input"
              name="load_more_button_text"
              onChange={this.onTextFieldChange}
              value={load_more_button_text}
            />
          </div>
        </div>
      </div>
    );
  }

  onCssChange( value ) {
    this.props.onFromValueChnage( 'custom_css', value );
  }

  onLoadMoreOptionChange( value ) {
    this.props.onFromValueChnage( 'show_load_more_button', Number(value) );
  }

  handleCacheTimeChange( event ) {
    var value = parseInt( event.target.value );
    if ( ! value || value < 10 ) {
      value = 10;
    }

    this.props.onFromValueChnage( 'cache_time', value );
  }

  onTextFieldChange( event ) {
    this.props.onFromValueChnage( event.target.name, event.target.value );
  }

}

export default SettingsFrom;
