import React from 'react';
import { connect } from 'react-redux';
import { notify } from 'react-notify-toast';

import SettingsFrom from '../SettingsFrom';
import { updateLoading } from '../../store';

class Settings extends React.Component {

  constructor(props) {
    super(props);

    this.state = {
      form: {
        cache_time: '60',
        custom_css: '',
        show_load_more_button: '1',
        load_more_button_text: 'Load More',
      }
    };

    this.updateFromValue = this.updateFromValue.bind(this);
    this.saveSettings = this.saveSettings.bind(this);
  }

  render() {
    return (
      <div className="gs-instagram-page-wrapper">
        <div className="gs-instagram-page-heading">
          <p className="gs-title">Settings</p>
          <p className="gs-subtitle">This is your global settings. These settings will be applied to each instagram theme.</p>
        </div>

        <SettingsFrom form={this.state.form} onFromValueChnage={this.updateFromValue} />

        <div>
          <button className="gs-instagram-button" onClick={this.saveSettings}>Save Settings</button>
          <span className="spinner gs-form-spinner" style={{ visibility: this.props.loading ? 'visible' : 'hidden' }}></span>
        </div>
      </div>
    );
  }

  updateFromValue( name, value ) {
    var form = this.state.form;
    form[ name ] = value
    this.setState( { form } );
  }

  saveSettings() {
    this.props.updateLoading( true );

    jQuery.ajax({
      method: "POST",
      url: window.ajaxurl,
      data: {
        body: this.state.form,
        action: "gs_instagram_admin_ajax",
        route: "save_settings",
      },
      success: ( response ) => {
        this.props.updateLoading( false );
        notify.show('Settings saved successfully!', 'success');
      }
    });
  }

  componentDidMount() {
    jQuery.ajax({
      method: "GET",
      url: window.ajaxurl + '?action=gs_instagram_admin_ajax&route=get_settings',
      success: ( response ) => {
        let data = Object.assign( this.state.form, response.data );
        this.setState( { form: data } );
      }
    });
  }

}

function mapStateToProps( state ) {
  return { loading: state.loading };
}

function mapDispatchToProps( dispatch ) {
  return {
    updateLoading: value => dispatch( updateLoading( value ) )
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(Settings);
