<?php
/**
 * Plugin Name: GS Insever Portfolio Lite
 * Plugin URI: https://www.gsplugins.com/wordpress-plugins/
 * Description: Instagram plugin for WordPress to showcase Instagram feeds or tags on your website without API Key. Display Instagram posts in engaging views. Generate shortcode and display anywhere at your site. Check more shortcode examples and documentation at <a href="http://instagram.gsplugins.com">GS Instagram Porfolio PRO Demos & Docs</a>
 * Author: GS Plugins
 * Author URI: https://gsplugins.com
 * Version: 1.4.4
 * Text Domain: gs-instagram
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * The class that holds the entire `GS Instagram Portfolio Pro` plugin
 * This is the starting point.
 *
 * @class GS_Instagram_Portfolio_Lite
 */
final class GS_Instagram_Portfolio_Lite {

    /**
     * Plugin version
     *
     * @var string
     */
    public $version = '1.4.4';

    /**
     * The single instance of the class.
     */
    protected static $_instance = null;

    /**
     * Initializes the GS_Instagram_Portfolio_Lite() class
     *
     * Checks for an existing GS_Instagram_Portfolio_Lite() instance and if it doesn't find one, creates it.
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

    /**
     * Constructor of GS_Instagram_Portfolio_Lite class
     * Sets up all the appropriate hooks
     */
    private function __construct() {
        $this->define_constants();

        $this->require_classes();

        $this->load_public();

        $this->load_admin();
    }

    /**
     * Define necessary constants
     */
    private function define_constants() {
        // common
        define( 'GS_INSTAGRAM_VERSION', $this->version );
        define( 'GS_INSTAGRAM__FILE__', __FILE__ );
        define( 'GS_INSTAGRAM_ROOT_PATH', plugin_dir_path( __FILE__ ) );
        define( 'GS_INSTAGRAM_ROOT_URL', plugins_url( '/', __FILE__ ) );

        // public
        define( 'GS_INSTAGRAM_PUBLIC_PATH', GS_INSTAGRAM_ROOT_PATH . 'public' );
        define( 'GS_INSTAGRAM_PUBLIC_ASSETS_URL', GS_INSTAGRAM_ROOT_URL . 'public/assets' );

        // admin
        define( 'GS_INSTAGRAM_ADMIN_PATH', GS_INSTAGRAM_ROOT_PATH . 'admin' );
        define( 'GS_INSTAGRAM_ADMIN_ASSETS_URL', GS_INSTAGRAM_ROOT_URL . 'admin/assets' );
    }

    /**
     * Run public functionality
     */
    private function load_public() {
        require GS_INSTAGRAM_PUBLIC_PATH . '/Frontend_Builder.php';

        GS_Instagram\Frontend_Builder::instance();
    }

    /**
     * Run admin functionality
     */
    private function load_admin() {
        require GS_INSTAGRAM_ADMIN_PATH . '/Backend_Builder.php';

        GS_Instagram\Backend_Builder::instance();
    }

    /**
     * Require necessary classes
     */
    private function require_classes() {
        require GS_INSTAGRAM_ROOT_PATH . 'common/Instagram_Client.php';
        require GS_INSTAGRAM_ROOT_PATH . 'common/Curl.php';
        require GS_INSTAGRAM_ROOT_PATH . 'common/Instagram_Model.php';
    }

}

GS_Instagram_Portfolio_Lite::instance();

/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_gs_instagram_portfolio() {

    if ( ! class_exists( 'Appsero\Client' ) ) {
      require_once GS_INSTAGRAM_ADMIN_PATH . '/appsero/src/Client.php';
    }

    $client = new Appsero\Client( '2a4f210b-bb7b-42d0-98f8-e42a738beedc', 'GS Insever Portfolio', __FILE__ );

    // Active insights
    $client->insights()->init();

}

appsero_init_tracker_gs_instagram_portfolio();
